package containers

  1. Overview
  2. Docs
On This Page
  1. IO
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module CCEitherSource

Either Monad

Module that is compatible with Either from OCaml 4.12 but can be use with any ocaml version compatible with container

  • since 3.2
Sourcetype 'a iter = ('a -> unit) -> unit
Sourcetype 'a equal = 'a -> 'a -> bool
Sourcetype 'a ord = 'a -> 'a -> int
Sourcetype 'a printer = Format.formatter -> 'a -> unit
Sourcetype ('a, 'b) t = ('a, 'b) Either.t =
  1. | Left of 'a
  2. | Right of 'b

This module defines the common Either interface that is provided for all OCaml versions. For documentation of these functions, refer to the standard library.

Sourceval left : 'a -> ('a, 'b) t
Sourceval right : 'b -> ('a, 'b) t
Sourceval is_left : ('a, 'b) t -> bool
Sourceval is_right : ('a, 'b) t -> bool
Sourceval find_left : ('a, 'b) t -> 'a option
Sourceval find_right : ('a, 'b) t -> 'b option
Sourceval map_left : ('a1 -> 'a2) -> ('a1, 'b) t -> ('a2, 'b) t
Sourceval map_right : ('b1 -> 'b2) -> ('a, 'b1) t -> ('a, 'b2) t
Sourceval map : left:('a1 -> 'a2) -> right:('b1 -> 'b2) -> ('a1, 'b1) t -> ('a2, 'b2) t
Sourceval fold : left:('a -> 'c) -> right:('b -> 'c) -> ('a, 'b) t -> 'c
Sourceval iter : left:('a -> unit) -> right:('b -> unit) -> ('a, 'b) t -> unit
Sourceval for_all : left:('a -> bool) -> right:('b -> bool) -> ('a, 'b) t -> bool
Sourceval equal : left:('a -> 'a -> bool) -> right:('b -> 'b -> bool) -> ('a, 'b) t -> ('a, 'b) t -> bool
Sourceval compare : left:('a -> 'a -> int) -> right:('b -> 'b -> int) -> ('a, 'b) t -> ('a, 'b) t -> int

IO

Sourceval pp : left:'a printer -> right:'b printer -> ('a, 'b) t printer

Pretty printer.